from pydantic import BaseModel, Field
from typing import List, Optional, Any

class ConnectRequest(BaseModel):
    username: str = Field(..., description="天勤账号")
    password: str = Field(..., description="天勤密码")

class ConnectResponse(BaseModel):
    success: bool
    message: str

class ContractResponse(BaseModel):
    success: bool
    data: List[Any] | Any

class TickResponse(BaseModel):
    success: bool
    data: Any

class KlineResponse(BaseModel):
    success: bool
    data: List[Any]

class DisconnectResponse(BaseModel):
    success: bool
    message: str
